@@ -25,16 +25,17 @@
     googleAuthR.scopes.selected = scopes_split("GAR_SCOPES"),
     googleAuthR.webapp.port = 1221,
     googleAuthR.jsonlite.simplifyVector = TRUE,
-    googleAuthR.ok_content_types = c("application/json; charset=UTF-8", "text/html; charset=UTF-8"),
+    googleAuthR.ok_content_types = c("application/json; charset=UTF-8", 
+                                     "text/html; charset=UTF-8"),
     googleAuthR.securitycode = 
-      paste0(sample(c(1:9, LETTERS, letters), 20, replace = T), collapse = ''),
+      paste0(sample(c(1:9, LETTERS, letters), 20, replace = TRUE), collapse = ''),
     googleAuthR.tryAttempts = 5,
     googleAuthR.HttrRetryTimes = 3,
     googleAuthR.HttrRetryTerminateOn = c(400,401,402,403,404,405,406,407,408,
                                          409,410,411,412,413,414,415,416,417,
                                          418,421,422,423,424,426,428,
                                          431,451),
-    googleAuthR.redirect = "default"
+    googleAuthR.redirect = paste("http://localhost:1221")
   )
   toset <- !(names(op.googleAuthR) %in% names(op))
   if (any(toset)) options(op.googleAuthR[toset])
